@@ -9,7 +9,10 @@ use Path::Tiny;
 use Fcntl qw/:seek/;
 use Encode;
 use String::Copyright;
-use String::Copyright 0.002 { threshold_after => 5 },
+use String::Copyright 0.002 {
+	threshold_after => 5,
+	format          => sub { join ' ', $_->[0] || (), $_->[1] || () },
+	},
 	'copyright' => { -as => 'copyright_optimistic' };
 
 use Moo;
@@ -23,11 +26,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.0.19
+Version v3.0.20
 
 =cut
 
-our $VERSION = version->declare("v3.0.19");
+our $VERSION = version->declare("v3.0.20");
 
 =head1 SYNOPSIS
 
